@@ -1,4 +1,5 @@
-from impedance.fitting import buildCircuit, rmse
+from impedance.models.circuits.fitting import buildCircuit, rmse, \
+                                              extract_circuit_elements
 import numpy as np
 
 # def test_residuals():
@@ -14,7 +15,7 @@ import numpy as np
 def test_buildCircuit():
 
     # Test simple Randles circuit with CPE
-    circuit = 'R0-p(R1-W1,E1)'
+    circuit = 'R0-p(R1-Wo1,CPE1)'
     params = [.1, .01, 1, 1000, 15, .9]
     frequencies = [1000.0, 5.0, 0.01]
 
@@ -22,8 +23,8 @@ def test_buildCircuit():
                         constants={})[0].replace(' ', '') == \
         's([R([0.1],[1000.0,5.0,0.01]),' + \
         'p([s([R([0.01],[1000.0,5.0,0.01]),' + \
-        'W([1.0,1000.0],[1000.0,5.0,0.01])]),' + \
-        'E([15.0,0.9],[1000.0,5.0,0.01])])])'
+        'Wo([1.0,1000.0],[1000.0,5.0,0.01])]),' + \
+        'CPE([15.0,0.9],[1000.0,5.0,0.01])])])'
 
     # Test multiple parallel elements
     circuit = 'R0-p(C1,R1,R2)'
@@ -72,3 +73,9 @@ def test_RMSE():
     c = np.array([2 + 4*1j, 1 + 4*1j])
     d = np.array([4 + 2*1j, 3 + 2*1j])
     assert np.isclose(rmse(c, d), 2*np.sqrt(2))
+
+
+def test_element_extraction():
+    circuit = 'R0-p(RR0,C1)-p(R1,C2032478)-W1'
+    extracted_elements = extract_circuit_elements(circuit)
+    assert extracted_elements == ['R0', 'RR0', 'C1', 'R1', 'C2032478', 'W1']
