@@ -1,8 +1,7 @@
 from impedance.preprocessing import readFile, readGamry, ignoreBelowX
-from impedance.preprocessing import readZPlot, readVersaStudio
-from impedance.preprocessing import readPowerSuite, readBioLogic
-from impedance.preprocessing import cropFrequencies
+from impedance.preprocessing import readZPlot, cropFrequencies
 import numpy as np
+import os
 
 # store some global test data
 frequencies = np.array([0.0031623, 0.0039811, 0.0050119, 0.0063096,
@@ -64,63 +63,27 @@ imag = [-0.020438698544418925, -0.0182856893045487, -0.016343158966700824,
         0.002452846099159856, 0.003488131035300228, 0.004712940823286973,
         0.006239444322658155, 0.008031686651315248, 0.010157474564938236]
 
-imag_np = [-0.020438698544418925,
-           -0.0182856893045487,
-           -0.016343158966700824,
-           -0.014589168660649915,
-           -0.01300096361736358,
-           -0.011573009182824043,
-           -0.010282133623145187,
-           -0.009113366697002839,
-           -0.00804494958277692,
-           -0.007075702921918925,
-           -0.006209940124316647,
-           -0.005450664199993216,
-           -0.004804611324614652,
-           -0.0042630212172992624,
-           -0.003816723014957778,
-           -0.003465230467686932,
-           -0.0031936182833490197,
-           -0.0029843274850640607,
-           -0.0028420187384119175,
-           -0.0027510821389620833,
-           -0.0027092774650327093,
-           -0.002716402585530142,
-           -0.0027688021541761596,
-           -0.0028687505233332576,
-           -0.002995332546857452,
-           -0.0031633863009665544,
-           -0.0034345232421858604,
-           -0.003652697342055591,
-           -0.00389594513544332,
-           -0.0041496368125138496,
-           -0.0043563647278047945,
-           -0.004528514961203703,
-           -0.004623972802104744,
-           -0.00463483440841946,
-           -0.004562544489738368,
-           -0.0044183840649258165,
-           -0.004213943600562558,
-           -0.00397620055979716,
-           -0.0037290248504921668,
-           -0.0035578892246933775,
-           -0.0033509582749051627,
-           -0.0031826464281827804,
-           -0.0030507184111723995,
-           -0.0029386920239828154,
-           -0.002848034411523496,
-           -0.0027583877127425357,
-           -0.0026767011351060705,
-           -0.002575856490231119,
-           -0.002455805016755156,
-           -0.0023163152672671405,
-           -0.002149498808757098,
-           -0.0019492643145405137,
-           -0.0017151675874650793,
-           -0.0014357936694323731,
-           -0.001109438368794195,
-           -0.0007287022309982213,
-           -0.0002827724289657194]
+Zi_np = [-0.020438698544418925, -0.0182856893045487, -0.016343158966700824,
+         -0.014589168660649915, -0.01300096361736358, -0.011573009182824043,
+         -0.010282133623145187, -0.009113366697002839, -0.00804494958277692,
+         -0.007075702921918925, -0.006209940124316647, -0.005450664199993216,
+         -0.004804611324614652, -0.0042630212172992624, -0.003816723014957778,
+         -0.003465230467686932, -0.0031936182833490197, -0.0029843274850640607,
+         -0.0028420187384119175, -0.0027510821389620833,
+         -0.0027092774650327093, -0.002716402585530142, -0.0027688021541761596,
+         -0.0028687505233332576, -0.002995332546857452, -0.0031633863009665544,
+         -0.0034345232421858604, -0.003652697342055591, -0.00389594513544332,
+         -0.0041496368125138496, -0.0043563647278047945, -0.004528514961203703,
+         -0.004623972802104744, -0.00463483440841946, -0.004562544489738368,
+         -0.0044183840649258165, -0.004213943600562558, -0.00397620055979716,
+         -0.0037290248504921668, -0.0035578892246933775,
+         -0.0033509582749051627, -0.0031826464281827804,
+         -0.0030507184111723995, -0.0029386920239828154, -0.002848034411523496,
+         -0.0027583877127425357, -0.0026767011351060705, -0.002575856490231119,
+         -0.002455805016755156, -0.0023163152672671405, -0.002149498808757098,
+         -0.0019492643145405137, -0.0017151675874650793,
+         -0.0014357936694323731, -0.001109438368794195, -0.0007287022309982213,
+         -0.0002827724289657194]
 
 Z_correct = np.array(real) + 1j * np.array(imag)
 
@@ -177,36 +140,15 @@ Zi_gamry = np.array([-1367.239, -1502.195, -1621.813, -1672.93, -1668.395,
 
 Z_gamry = Zr_gamry + 1j * Zi_gamry
 
-freq_powersuite = np.array([0.1,
-                            0.17854992,
-                            0.31880073,
-                            0.56921845,
-                            1.0163391,
-                            1.8146726,
-                            3.2400964,
-                            5.7851894,
-                            10.329451,
-                            18.443226,
-                            32.930365,
-                            58.79714,
-                            104.98225,
-                            187.44571,
-                            334.68417,
-                            597.57831,
-                            1066.9756,
-                            1905.084,
-                            3401.526,
-                            6073.4218,
-                            10844.09,
-                            19362.113,
-                            34571.037,
-                            61726.559,
-                            110212.72,
-                            196784.72,
-                            351358.96,
-                            627351.13,
-                            1120134.9,
-                            2000000])
+f_powersuite = np.array([0.1, 0.17854992, 0.31880073, 0.56921845,
+                         1.0163391, 1.8146726, 3.2400964, 5.7851894,
+                         10.329451, 18.443226, 32.930365, 58.79714,
+                         104.98225, 187.44571, 334.68417, 597.57831,
+                         1066.9756, 1905.084, 3401.526, 6073.4218, 10844.09,
+                         19362.113, 34571.037, 61726.559, 110212.72,
+                         196784.72, 351358.96, 627351.13, 1120134.9,
+                         2000000])
+
 f_VerStu = np.array([100000, 77426.37, 59948.43, 46415.89, 35938.14,
                      27825.59, 21544.35, 16681.01, 12915.5, 10000, 7742.637,
                      5994.842, 4641.589, 3593.814, 2782.559,
@@ -221,67 +163,22 @@ f_VerStu = np.array([100000, 77426.37, 59948.43, 46415.89, 35938.14,
                      0.05994843, 0.04641589, 0.03593814, 0.02782559,
                      0.02154435])
 
-Zr_powersuite = np.array([423929.46,
-                          407724.77,
-                          393610.92,
-                          380855.3,
-                          368303.75,
-                          355620.08,
-                          342669.59,
-                          326400.15,
-                          310309.77,
-                          293257.73,
-                          272125.84,
-                          257101.27,
-                          246617.86,
-                          236526.34,
-                          229582.56,
-                          222018.3,
-                          215427.54,
-                          208362.26,
-                          200923.4,
-                          192890.56,
-                          181958.74,
-                          152457.91,
-                          98568.678,
-                          30854.758,
-                          4716.4675,
-                          4266.6691,
-                          4175.3844,
-                          4713.6726,
-                          -1075.6649,
-                          -470.54113])
+Zr_powersuite = np.array([423929.46, 407724.77, 393610.92, 380855.3, 368303.75,
+                          355620.08, 342669.59, 326400.15, 310309.77,
+                          293257.73, 272125.84, 257101.27, 246617.86,
+                          236526.34, 229582.56, 222018.3, 215427.54, 208362.26,
+                          200923.4, 192890.56, 181958.74, 152457.91, 98568.678,
+                          30854.758, 4716.4675, 4266.6691, 4175.3844,
+                          4713.6726, -1075.6649, -470.54113])
 
-Zi_powersuite = np.array([-49014.063,
-                          -44951.636,
-                          -41207.904,
-                          -38609.417,
-                          -38403.847,
-                          -38865.422,
-                          -40856.382,
-                          -42072.753,
-                          -42701.163,
-                          -43531.868,
-                          -41773.454,
-                          -49735.17,
-                          -23804.949,
-                          -16131.9,
-                          -24428.137,
-                          -21951.26,
-                          -20820.892,
-                          -20101.991,
-                          -30050.48,
-                          -40284.586,
-                          -62039.679,
-                          -86830.249,
-                          -105476.2,
-                          -90093.313,
-                          -50840.594,
-                          -25846.006,
-                          -14003.348,
-                          -4331.2465,
-                          -713.75358,
-                          -1397.7358])
+Zi_powersuite = np.array([-49014.063, -44951.636, -41207.904, -38609.417,
+                          -38403.847, -38865.422, -40856.382, -42072.753,
+                          -42701.163, -43531.868, -41773.454, -49735.17,
+                          -23804.949, -16131.9, -24428.137, -21951.26,
+                          -20820.892, -20101.991, -30050.48, -40284.586,
+                          -62039.679, -86830.249, -105476.2, -90093.313,
+                          -50840.594, -25846.006, -14003.348, -4331.2465,
+                          -713.75358, -1397.7358])
 
 Z_powersuite = Zr_powersuite + 1j * Zi_powersuite
 
@@ -315,47 +212,50 @@ Zi_VerStu = np.array([4.575431, 1.668054, -0.03684627, -1.969503, -2.897054,
 
 Z_VerStu = Zr_VerStu + 1j * Zi_VerStu
 
+# Data for ZPlot file with comments in header
 f_ZPlot = np.array([3.000000e+05, 2.382985e+05, 1.892872e+05, 1.503562e+05,
                     1.194321e+05, 9.486833e+04, 7.535659e+04, 5.985787e+04,
                     4.754680e+04, 3.776776e+04, 3.000000e+04, 2.382985e+04,
                     1.892872e+04, 1.503562e+04, 1.194321e+04, 9.486833e+03,
                     7.535659e+03, 5.985787e+03, 4.754680e+03, 3.776776e+03,
-                    3.000000e+03, 2.382985e+03, 1.892872e+03, 1.503562e+03,
-                    1.194322e+03, 9.486833e+02, 7.535659e+02, 5.985787e+02,
-                    4.754680e+02, 3.776776e+02, 3.000000e+02, 2.382985e+02,
-                    1.892872e+02, 1.503562e+02, 1.194322e+02, 9.486833e+01,
-                    7.535659e+01, 5.985787e+01, 4.754680e+01, 3.776776e+01,
-                    3.000000e+01, 2.382985e+01, 1.892872e+01, 1.503562e+01,
-                    1.194322e+01, 9.486830e+00, 7.535660e+00, 5.985790e+00,
-                    4.754680e+00, 3.776780e+00, 3.000000e+00, 2.382980e+00,
-                    1.892870e+00, 1.503560e+00, 1.194320e+00, 1.000000e+00])
+                    3.000000e+03])
 
 Zr_ZPlot = np.array([147.77, 148.93, 150.48, 151.46, 153.2, 155.62, 158.98,
                      164.45, 172.73, 184.99, 203.10, 228.85, 264.03, 309.13,
-                     362.59, 419.55, 475.02, 523.25, 563.36, 590.31, 613.68,
-                     626.31, 635.67, 641.11, 645.33, 648.19, 649.75, 650.67,
-                     652.12, 651.82, 653.25, 652.64, 652.37, 653.05, 651.39,
-                     653.11, 652.42, 654.90, 653.10, 653.17, 653.14, 653.53,
-                     652.66, 653.13, 652.79, 652.05, 653.44, 651.58, 650.93,
-                     653.24, 654.68, 652.33, 652.27, 652.48, 653.25, 654.19])
+                     362.59, 419.55, 475.02, 523.25, 563.36, 590.31, 613.68])
 
 Zi_ZPlot = np.array([-1.1335e+01, -1.7302e+01, -2.3653e+01, -3.1301e+01,
                      -4.0748e+01, -5.2177e+01, -6.5761e+01, -8.2536e+01,
                      -1.0261e+02, -1.2607e+02, -1.5276e+02, -1.8117e+02,
                      -2.0876e+02, -2.3205e+02, -2.4704e+02, -2.4885e+02,
                      -2.3945e+02, -2.1885e+02, -1.9176e+02, -1.6694e+02,
-                     -1.3713e+02, -1.1137e+02, -9.0614e+01, -7.1190e+01,
-                     -5.9297e+01, -4.6257e+01, -3.6456e+01, -3.0742e+01,
-                     -2.3792e+01, -1.8864e+01, -1.2276e+01, -1.1308e+01,
-                     -9.5142e+00, -7.6985e+00, -6.3635e+00, -4.9270e+00,
-                     -4.3839e+00, -1.4622e+00, -2.0900e+00, -1.8532e+00,
-                     -1.7382e+00, -1.4767e+00, -8.4596e-01, -1.3005e+00,
-                     -1.1834e+00, -1.1508e+00, -8.3833e-01, -7.0630e-01,
-                     8.1795e-02, 6.2940e-01, 1.6343e-01, 5.4773e-01,
-                     -5.1657e-01, 1.6725e+00, -1.2792e-01, 6.4271e-01])
+                     -1.3713e+02])
 
 Z_ZPlot = Zr_ZPlot + 1j * Zi_ZPlot
 
+# Data for ZPlot file without comments in header
+f_ZPlot2 = np.array([300000., 238298.5, 189287.2, 150356.2, 119432.1,
+                     94868.33, 75356.59, 59857.87, 47546.8, 37767.76,
+                     30000., 23829.85, 18928.72, 15035.62, 11943.21,
+                     9486.833, 7535.659, 5985.787, 4754.68, 3776.776,
+                     3000., 2382.985, 1892.872, 1503.562, 1194.322,
+                     948.6833, 753.5659, 598.5787, 475.468, 377.6776, 300.])
+
+Zr_ZPlot2 = np.array([642.62, 674.77, 706.56, 726.44, 752.79, 768.68, 791.48,
+                      802.65, 833.44, 861.09, 883.88, 909.47, 938.49, 965.33,
+                      991.13, 1017.5, 1040.4, 1064.1, 1087.7, 1102.8, 1124.2,
+                      1141.3, 1155.7, 1173.6, 1192., 1207.9, 1226.5, 1245.1,
+                      1264.1, 1285.7, 1305.3])
+
+Zi_ZPlot2 = np.array([-85.821, -119.31, -119.85, -126.82, -138.78, -133.84,
+                      -135.98, -141.73, -150.21, -154.89, -160.49, -161.84,
+                      -165.16, -164.33, -158.15, -158.86, -154.85, -148.36,
+                      -146.13, -140.9, -137.18, -136.67, -137.45, -138.8,
+                      -142.51, -146.61, -153.77, -161.62, -171.3, -182.73,
+                      -195.01])
+
+Z_ZPlot2 = Zr_ZPlot2 + 1j * Zi_ZPlot2
+
 f_BioLogic = np.array([1.00032010e+03, 7.70246580e+02, 5.92912840e+02,
                        4.56314090e+02, 3.51010830e+02, 2.70432650e+02,
                        2.07937190e+02, 1.60256390e+02, 1.23303310e+02,
@@ -396,47 +296,183 @@ Zi_BioLogic = np.array([-0.38998979, -1.3082615, 0.49220982, -1.1641068,
 
 Z_BioLogic = Zr_BioLogic + 1j * Zi_BioLogic
 
+f_CHInstruments = np.array([9.961e+4, 8.252e+4, 6.812e+4, 5.625e+4, 4.644e+4,
+                            3.833e+4, 3.164e+4, 2.612e+4, 2.153e+4, 1.777e+4,
+                            1.470e+4, 1.211e+4, 1.001e+4, 8.252e+3, 6.812e+3,
+                            5.625e+3, 4.643e+3, 3.833e+3, 3.164e+3, 2.612e+3,
+                            2.153e+3, 1.777e+3, 1.470e+3, 1.211e+3, 1.001e+3,
+                            8.252e+2, 6.836e+2, 5.615e+2, 4.639e+2, 3.809e+2,
+                            3.174e+2, 2.588e+2, 2.148e+2, 1.758e+2, 1.465e+2,
+                            1.221e+2, 9.766e+1, 8.254e+1, 6.813e+1, 5.623e+1,
+                            4.642e+1, 3.831e+1, 3.162e+1, 2.610e+1, 2.154e+1,
+                            1.778e+1, 1.468e+1, 1.212e+1, 1.000e+1, 8.254e+0,
+                            6.813e+0, 5.623e+0, 4.642e+0, 3.831e+0, 3.162e+0,
+                            2.610e+0, 2.154e+0, 1.778e+0, 1.468e+0, 1.212e+0,
+                            1.000e+0, 8.254e-1, 6.813e-1, 5.623e-1, 4.642e-1,
+                            3.831e-1, 3.162e-1, 2.610e-1, 2.154e-1, 1.778e-1,
+                            1.468e-1, 1.212e-1, 1.000e-1
+                            ])
+
+Zr_CHInst = np.array([9.891e+1, 9.912e+1, 9.911e+1, 9.922e+1, 9.931e+1,
+                      9.947e+1, 9.965e+1, 9.989e+1, 1.002e+2, 1.005e+2,
+                      1.008e+2, 1.012e+2, 1.017e+2, 1.023e+2, 1.029e+2,
+                      1.036e+2, 1.045e+2, 1.055e+2, 1.066e+2, 1.080e+2,
+                      1.098e+2, 1.119e+2, 1.144e+2, 1.174e+2, 1.212e+2,
+                      1.256e+2, 1.310e+2, 1.373e+2, 1.447e+2, 1.532e+2,
+                      1.630e+2, 1.742e+2, 1.868e+2, 2.008e+2, 2.159e+2,
+                      2.333e+2, 2.524e+2, 2.727e+2, 2.949e+2, 3.189e+2,
+                      3.450e+2, 3.734e+2, 4.041e+2, 4.373e+2, 4.731e+2,
+                      5.118e+2, 5.533e+2, 5.975e+2, 6.445e+2, 6.954e+2,
+                      7.508e+2, 8.108e+2, 8.766e+2, 9.469e+2, 1.023e+3,
+                      1.107e+3, 1.200e+3, 1.301e+3, 1.401e+3, 1.507e+3,
+                      1.628e+3, 1.763e+3, 1.908e+3, 2.070e+3, 2.253e+3,
+                      2.468e+3, 2.722e+3, 3.022e+3, 3.380e+3, 3.805e+3,
+                      4.315e+3, 4.939e+3, 5.685e+3,
+                      ])
+
+Zi_CHInst = np.array([-2.748e+0, 1.603e+0, 7.538e-1, 6.836e-1, -7.515e-1,
+                      -1.521e+0, -2.508e+0, -3.224e+0, -4.086e+0, -4.955e+0,
+                      -5.964e+0, -7.081e+0, -8.357e+0, -9.789e+0, -1.141e+1,
+                      -1.327e+1, -1.543e+1, -1.796e+1, -2.088e+1, -2.427e+1,
+                      -2.817e+1, -3.261e+1, -3.769e+1, -4.344e+1, -4.991e+1,
+                      -5.711e+1, -6.517e+1, -7.416e+1, -8.405e+1, -9.467e+1,
+                      -1.062e+2, -1.187e+2, -1.320e+2, -1.462e+2, -1.611e+2,
+                      -1.776e+2, -1.954e+2, -2.141e+2, -2.345e+2, -2.568e+2,
+                      -2.813e+2, -3.081e+2, -3.376e+2, -3.704e+2, -4.068e+2,
+                      -4.475e+2, -4.934e+2, -5.452e+2, -6.041e+2, -6.721e+2,
+                      -7.510e+2, -8.430e+2, -9.518e+2, -1.077e+3, -1.227e+3,
+                      -1.404e+3, -1.636e+3, -1.920e+3, -2.221e+3, -2.548e+3,
+                      -2.894e+3, -3.289e+3, -3.761e+3, -4.316e+3, -4.964e+3,
+                      -5.712e+3, -6.586e+3, -7.607e+3, -8.791e+3, -1.017e+4,
+                      -1.178e+4, -1.367e+4, -1.586e+4
+                      ])
+
+Z_CHInst = Zr_CHInst + 1j * Zi_CHInst
+
+f_Parstat = \
+    np.array([10000., 7943.28222656, 6309.57324219, 5011.87304688,
+              3981.07202148, 3162.27807617, 2511.88598633, 1995.26196289,
+              1584.89294434, 1258.92504883, 1000., 794.32818604, 630.95727539,
+              501.18719482, 398.10720825, 316.22781372, 251.18859863,
+              199.52619934, 158.48930359, 125.89250183, 100., 79.43282318,
+              63.09572983, 50.11872101, 39.81071854, 31.62277985, 25.11886024,
+              19.95261955, 15.84893036, 12.58924961, 10.])
+Z_Parstat = \
+    np.array([-0.00049816,  0.03113425,  0.03085655,  0.02750344,  0.02587598,
+              0.02262978,  0.0163767,  0.01642007,  0.01641888,  0.01648767,
+              0.01664307,  0.01675913,  0.01708486,  0.01743512,  0.01784903,
+              0.01840109,  0.01886718,  0.01942232,  0.01993291,  0.02046922,
+              0.02103856,  0.02155352,  0.02209521,  0.02254164,  0.02316423,
+              0.02369809,  0.02432287,  0.02493612,  0.02567521,  0.02636954,
+              0.02709465]) + \
+    np.array([1.75143480e-02, 1.14148268e-02, 1.30274916e-02, 9.78105741e-03,
+              9.01670213e-03, 5.71952550e-03, 3.52889603e-03, 2.53371177e-03,
+              1.65629638e-03, 8.17670784e-04, -5.96813004e-06,
+              -6.22442740e-04, -1.19255408e-03, -1.68640339e-03,
+              -2.08737738e-03, -2.44086429e-03, -2.70580579e-03,
+              -2.90602728e-03, -3.10230667e-03, -3.23357190e-03,
+              -3.31775800e-03, -3.45947806e-03, -3.55014394e-03,
+              -3.64250600e-03, -3.73602406e-03, -3.85300213e-03,
+              -3.95614285e-03, -4.05710706e-03, -4.05976692e-03,
+              -4.07387413e-03, -3.99791080e-03]) * 1j
+
+f_Autolab = \
+    np.array([1.0000e+04, 7.4989e+03, 5.6234e+03, 4.2170e+03, 3.1623e+03,
+              2.3714e+03, 1.7783e+03, 1.3335e+03, 1.0000e+03, 7.4989e+02,
+              5.6234e+02, 4.2170e+02, 3.1623e+02, 2.3714e+02, 1.7783e+02,
+              1.3335e+02, 1.0000e+02, 7.4989e+01, 5.6234e+01, 4.2170e+01,
+              3.1623e+01, 2.3714e+01, 1.7783e+01, 1.3335e+01, 1.0000e+01,
+              7.4989e+00, 5.6234e+00, 4.2170e+00, 3.1623e+00, 2.3714e+00,
+              1.7783e+00, 1.3335e+00, 1.0000e+00, 7.4989e-01, 5.6234e-01,
+              4.2170e-01, 3.1623e-01, 2.3714e-01, 1.7783e-01, 1.3335e-01,
+              1.0000e-01])
+
+Z_Autolab = \
+    np.array([0.01378586, 0.0134723, 0.01337314, 0.01334488, 0.01343512,
+              0.01362447, 0.01389368, 0.01419037, 0.01456457, 0.01500111,
+              0.01546253, 0.0160044, 0.01654863, 0.01711031, 0.01788554,
+              0.01846229, 0.01911284, 0.01978657, 0.0202417, 0.02090931,
+              0.02130499, 0.02206082, 0.02293594, 0.02374418, 0.02488619,
+              0.02606933, 0.02719578, 0.02819366, 0.02910203, 0.02984586,
+              0.03043904, 0.03101505, 0.03148148, 0.03187653, 0.03228522,
+              0.03265897, 0.0329814, 0.03335385, 0.03376434, 0.03414311,
+              0.03456978]) + \
+    np.array([0.00719195,  0.00523693,  0.0036207,  0.00232183,  0.00129639,
+              0.00043567, -0.00026718, -0.00086595, -0.00136828, -0.00181041,
+              -0.00217289, -0.00248625, -0.00270533, -0.00289687, -0.00312593,
+              -0.00325021, -0.00331533, -0.0034356, -0.00346742, -0.00352986,
+              -0.00396981, -0.00412786, -0.00446133, -0.00469385, -0.00493569,
+              -0.00496705, -0.00483047, -0.00464854, -0.00427596, -0.00385799,
+              -0.00355866, -0.00321351, -0.00293132, -0.00290529, -0.00267498,
+              -0.00315992, -0.00291614, -0.00296706, -0.00316768, -0.00342931,
+              -0.00390293]) * 1j
+
+example_files = {'gamry': 'exampleDataGamry.DTA',
+                 'gamry_abort': 'exampleDataGamryABORT.DTA',
+                 'autolab': 'exampleDataAutolab.txt',
+                 'parstat': 'exampleDataParstat.txt',
+                 'zplot': 'exampleDataZPlot.z',
+                 'versastudio': 'exampleDataVersaStudio.par',
+                 'powersuite': 'exampleDataPowersuite.txt',
+                 'biologic': 'exampleDataBioLogic.mpt',
+                 'chinstruments': 'exampleDataCHInstruments.txt',
+                 None: 'exampleData.csv'}
+
+f_checks = {'gamry': f_gamry,
+            'autolab': f_Autolab,
+            'parstat': f_Parstat,
+            'zplot': f_ZPlot,
+            'versastudio': f_VerStu,
+            'powersuite': f_powersuite,
+            'biologic': f_BioLogic,
+            'chinstruments': f_CHInstruments,
+            None: frequencies}
+
+Z_checks = {'gamry': Z_gamry,
+            'autolab': Z_Autolab,
+            'parstat': Z_Parstat,
+            'zplot': Z_ZPlot,
+            'versastudio': Z_VerStu,
+            'powersuite': Z_powersuite,
+            'biologic': Z_BioLogic,
+            'chinstruments': Z_CHInst,
+            None: Z_correct}
+
+directory = "data"
+
 
 def test_readFile():
-    f, Z = readFile('./data/exampleData.csv')
-
-    assert (f == frequencies).all() and (Z == Z_correct).all()
-
-
-def test_readBioLogic():
-    f, Z = readBioLogic('./data/exampleDataBioLogic.mpt')
-
-    assert (f == f_BioLogic).all() and (Z == Z_BioLogic).all()
+    for inst in Z_checks:
+        if example_files[inst]:
+            f, Z = readFile(os.path.join(directory, example_files[inst]), inst)
+            assert (np.isclose(f, f_checks[inst])).all() \
+                and (np.isclose(Z, Z_checks[inst])).all()
+    # assert (f == frequencies).all() and (Z == Z_correct).all()
 
 
 def test_readGamry():
-    f, Z = readGamry('./data/Chalco-in-buffer-50mV.DTA')
+    f, Z = readGamry(os.path.join(directory, example_files['gamry']))
+    f_abort, Z_abort = readGamry(os.path.join(directory,
+                                              example_files['gamry_abort']))
 
     assert (f == f_gamry).all() and (Z == Z_gamry).all()
-
-
-def test_readPowerSuite():
-    f, Z = readPowerSuite('./data/exampleDataPowersuite.txt')
-
-    assert (f == freq_powersuite).all() and (Z == Z_powersuite).all()
-
-
-def test_readVersaStudio():
-    f, Z = readVersaStudio('./data/exampleDataVersaStudio.par')
-
-    assert (f == f_VerStu).all() and (Z == Z_VerStu).all()
+    assert (f_abort == f_gamry).all() and (Z_abort == Z_gamry).all()
 
 
 def test_readZPlot():
-    f, Z = readZPlot('./data/exampleDataZPlot.z')
+    f, Z = readZPlot(os.path.join(".", directory, example_files['zplot']))
+    # Separate file to test for no comments in header
+    f2, Z2 = readZPlot(os.path.join(".", directory,
+                                    "exampleDataZPlot_noComments.z"))
 
     assert (f == f_ZPlot).all() and (Z == Z_ZPlot).all()
+    assert (f2 == f_ZPlot2).all() and (Z2 == Z_ZPlot2).all()
 
 
 def test_ignoreBelowX():
     filtered_freq, filtered_Z = ignoreBelowX(frequencies, Z_correct)
 
-    assert (np.imag(filtered_Z) == imag_np).all()
+    assert (np.imag(filtered_Z) == Zi_np).all()
 
 
 def test_cropFreq_maxonly():
